==> zio-aws-docdb_2.13-5.17.150.1-sources.jar: zio/aws/docdb/model/ModifyGlobalClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyGlobalClusterResponse(
    globalCluster: Option[zio.aws.docdb.model.GlobalCluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse = {
    import ModifyGlobalClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
      .builder()
      .optionallyWith(globalCluster.map(value => value.buildAwsValue()))(
        _.globalCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.ModifyGlobalClusterResponse.ReadOnly =
    zio.aws.docdb.model.ModifyGlobalClusterResponse.wrap(buildAwsValue())
}
object ModifyGlobalClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.ModifyGlobalClusterResponse =
      zio.aws.docdb.model.ModifyGlobalClusterResponse(
        globalCluster.map(value => value.asEditable)
      )
    def globalCluster: Option[zio.aws.docdb.model.GlobalCluster.ReadOnly]
    def getGlobalCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.GlobalCluster.ReadOnly] =
      AwsError.unwrapOptionField("globalCluster", globalCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
  ) extends zio.aws.docdb.model.ModifyGlobalClusterResponse.ReadOnly {
    override val globalCluster
        : Option[zio.aws.docdb.model.GlobalCluster.ReadOnly] = scala
      .Option(impl.globalCluster())
      .map(value => zio.aws.docdb.model.GlobalCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
  ): zio.aws.docdb.model.ModifyGlobalClusterResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-docdb_2.13-5.17.295.14-sources.jar: zio/aws/docdb/model/ModifyGlobalClusterResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyGlobalClusterResponse(
    globalCluster: Optional[zio.aws.docdb.model.GlobalCluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse = {
    import ModifyGlobalClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
      .builder()
      .optionallyWith(globalCluster.map(value => value.buildAwsValue()))(
        _.globalCluster
      )
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.ModifyGlobalClusterResponse.ReadOnly =
    zio.aws.docdb.model.ModifyGlobalClusterResponse.wrap(buildAwsValue())
}
object ModifyGlobalClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.ModifyGlobalClusterResponse =
      zio.aws.docdb.model.ModifyGlobalClusterResponse(
        globalCluster.map(value => value.asEditable)
      )
    def globalCluster: Optional[zio.aws.docdb.model.GlobalCluster.ReadOnly]
    def getGlobalCluster
        : ZIO[Any, AwsError, zio.aws.docdb.model.GlobalCluster.ReadOnly] =
      AwsError.unwrapOptionField("globalCluster", globalCluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
  ) extends zio.aws.docdb.model.ModifyGlobalClusterResponse.ReadOnly {
    override val globalCluster
        : Optional[zio.aws.docdb.model.GlobalCluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.globalCluster())
        .map(value => zio.aws.docdb.model.GlobalCluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.ModifyGlobalClusterResponse
  ): zio.aws.docdb.model.ModifyGlobalClusterResponse.ReadOnly = new Wrapper(
    impl
  )
}
